from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .dead_letter_envelope import DeadLetterEnvelope

@dataclass
class DeadLetterEnvelopeResults(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The databaseUri property
    database_uri: Optional[str] = None
    # The envelopes property
    envelopes: Optional[list[DeadLetterEnvelope]] = None
    # The pageNumber property
    page_number: Optional[int] = None
    # The totalCount property
    total_count: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> DeadLetterEnvelopeResults:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: DeadLetterEnvelopeResults
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return DeadLetterEnvelopeResults()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .dead_letter_envelope import DeadLetterEnvelope

        from .dead_letter_envelope import DeadLetterEnvelope

        fields: dict[str, Callable[[Any], None]] = {
            "databaseUri": lambda n : setattr(self, 'database_uri', n.get_str_value()),
            "envelopes": lambda n : setattr(self, 'envelopes', n.get_collection_of_object_values(DeadLetterEnvelope)),
            "pageNumber": lambda n : setattr(self, 'page_number', n.get_int_value()),
            "totalCount": lambda n : setattr(self, 'total_count', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("databaseUri", self.database_uri)
        writer.write_collection_of_object_values("envelopes", self.envelopes)
        writer.write_int_value("pageNumber", self.page_number)
        writer.write_int_value("totalCount", self.total_count)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .billing.billing_request_builder import BillingRequestBuilder
    from .usage.usage_request_builder import UsageRequestBuilder

class TenantRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /api/v1/tenant
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new TenantRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/api/v1/tenant", path_parameters)
    
    @property
    def billing(self) -> BillingRequestBuilder:
        """
        The billing property
        """
        from .billing.billing_request_builder import BillingRequestBuilder

        return BillingRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def usage(self) -> UsageRequestBuilder:
        """
        The usage property
        """
        from .usage.usage_request_builder import UsageRequestBuilder

        return UsageRequestBuilder(self.request_adapter, self.path_parameters)
    

